@@ -43,17 +43,17 @@
  *
  * ```xml
  * <object class="GtkWindow">
- *   <child type="titlebar">
+ *   <property name="titlebar">
  *     <object class="AdwHeaderBar">
  *       <property name="centering-policy">strict</property>
- *       <child type="title">
+ *       <property name="title-widget">
  *         <object class="AdwViewSwitcherTitle" id="title">
  *           <property name="stack">stack</property>
  *         </object>
  *       </child>
  *     </object>
- *   </child>
- *   <child>
+ *   </property>
+ *   <property>
  *     <object class="GtkBox">
  *       <property name="orientation">vertical</property>
  *       <child>
@@ -68,7 +68,7 @@
  *         </object>
  *       </child>
  *     </object>
- *   </child>
+ *   </property>
  * </object>
  * ```
  *
@@ -288,44 +288,38 @@ adw_view_switcher_title_class_init (AdwViewSwitcherTitleClass *klass)
    * Since: 1.0
    */
   props[PROP_STACK] =
-    g_param_spec_object ("stack",
-                         "Stack",
-                         "The stack the view switcher controls",
+    g_param_spec_object ("stack", NULL, NULL,
                          ADW_TYPE_VIEW_STACK,
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewSwitcherTitle:title: (attributes org.gtk.Property.get=adw_view_switcher_title_get_title org.gtk.Property.set=adw_view_switcher_title_set_title)
    *
    * The title to display.
    *
-   * The title should give a user additional details. A good title should not
-   * include the application name.
+   * The title typically identifies the current view or content item, and
+   * generally does not use the application name.
    *
    * Since: 1.0
    */
   props[PROP_TITLE] =
-    g_param_spec_string ("title",
-                         "Title",
-                         "The title to display",
+    g_param_spec_string ("title", NULL, NULL,
                          "",
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewSwitcherTitle:subtitle: (attributes org.gtk.Property.get=adw_view_switcher_title_get_subtitle org.gtk.Property.set=adw_view_switcher_title_set_subtitle)
    *
    * The subtitle to display.
    *
-   * The subtitle should give a user additional details.
+   * The subtitle should give the user additional details.
    *
    * Since: 1.0
    */
   props[PROP_SUBTITLE] =
-    g_param_spec_string ("subtitle",
-                         "Subtitle",
-                         "The subtitle to display",
+    g_param_spec_string ("subtitle", NULL, NULL,
                          "",
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewSwitcherTitle:view-switcher-enabled: (attributes org.gtk.Property.get=adw_view_switcher_title_get_view_switcher_enabled org.gtk.Property.set=adw_view_switcher_title_set_view_switcher_enabled)
@@ -342,11 +336,9 @@ adw_view_switcher_title_class_init (AdwViewSwitcherTitleClass *klass)
    * Since: 1.0
    */
   props[PROP_VIEW_SWITCHER_ENABLED] =
-    g_param_spec_boolean ("view-switcher-enabled",
-                         "View switcher enabled",
-                         "Whether the view switcher is enabled",
+    g_param_spec_boolean ("view-switcher-enabled", NULL, NULL,
                          TRUE,
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewSwitcherTitle:title-visible: (attributes org.gtk.Property.get=adw_view_switcher_title_get_title_visible)
@@ -359,11 +351,9 @@ adw_view_switcher_title_class_init (AdwViewSwitcherTitleClass *klass)
    * Since: 1.0
    */
   props[PROP_TITLE_VISIBLE] =
-    g_param_spec_boolean ("title-visible",
-                         "Title visible",
-                         "Whether the title is currently visible",
+    g_param_spec_boolean ("title-visible", NULL, NULL,
                          TRUE,
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -492,6 +482,9 @@ adw_view_switcher_title_get_title (AdwViewSwitcherTitle *self)
  *
  * Sets the title of @self.
  *
+ * The title typically identifies the current view or content item, and
+ * generally does not use the application name.
+ *
  * Since: 1.0
  */
 void
@@ -533,6 +526,8 @@ adw_view_switcher_title_get_subtitle (AdwViewSwitcherTitle *self)
  *
  * Sets the subtitle of @self.
  *
+ * The subtitle should give the user additional details.
+ *
  * Since: 1.0
  */
 void
@@ -574,6 +569,13 @@ adw_view_switcher_title_get_view_switcher_enabled (AdwViewSwitcherTitle *self)
  *
  * Sets whether @self's view switcher is enabled.
  *
+ * If it is disabled, the title will be displayed instead. This allows to
+ * programmatically hide the view switcher even if it fits in the available
+ * space.
+ *
+ * This can be used e.g. to ensure the view switcher is hidden below a certain
+ * window width, or any other constraint you find suitable.
+ *
  * Since: 1.0
  */
 void
@@ -599,6 +601,9 @@ adw_view_switcher_title_set_view_switcher_enabled (AdwViewSwitcherTitle *self,
  *
  * Gets whether the title of @self is currently visible.
  *
+ * If the title is visible, it means the view switcher is hidden an it may be
+ * wanted to show an alternative switcher, e.g. a [class@ViewSwitcherBar].
+ *
  * Returns: whether the title of @self is currently visible
  *
  * Since: 1.0
